<?php

/**
 * ⚠️ Editing not allowed except for 'en' language.
 *
 * @see https://github.com/monicahq/monica/blob/main/docs/contribute/translate.md for translations.
 */

return [
    'type_birthday' => 'נא לאחל יום הולדת שמח ל־',
    'type_phone_call' => 'שיחה',
    'type_lunch' => 'ארוחת צהריים עם',
    'type_hangout' => 'בילוי משותף עם',
    'type_email' => 'דוא״ל',
    'type_birthday_kid' => 'נא לאחל יום הולדת שמח לילד של',
];
